package com.ruoyi.interfaces.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.ruoyi.interfaces.domain.MdModelParams;
import com.ruoyi.interfaces.mapper.MdModelParamsMapper;
import com.ruoyi.interfaces.service.IMdModelParamsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 模型参数信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Service
public class MdModelParamsServiceImpl implements IMdModelParamsService
{
    @Autowired
    private MdModelParamsMapper mdModelParamsMapper;

    /**
     * 查询模型参数信息
     * 
     * @param parId 模型参数信息主键
     * @return 模型参数信息
     */
    @Override
    public MdModelParams selectMdModelParamsByParId(String parId)
    {
        return mdModelParamsMapper.selectMdModelParamsByParid(parId);
    }

    /**
     * 查询模型参数信息列表
     * 
     * @param mdModelParams 模型参数信息
     * @return 模型参数信息
     */
    @Override
    public List<MdModelParams> selectMdModelParamsList(MdModelParams mdModelParams)
    {
        return mdModelParamsMapper.selectMdModelParamsList(mdModelParams);
    }

    /**
     * 新增模型参数信息
     * 
     * @param mdModelParams 模型参数信息
     * @return 结果
     */
    @Override
    public int insertMdModelParams(MdModelParams mdModelParams)
    {
        mdModelParams.setParid(IdUtils.fastUUID());
        mdModelParams.setCreateby(DateUtils.getNowDate());
        return mdModelParamsMapper.insertMdModelParams(mdModelParams);
    }

    /**
     * 修改模型参数信息
     * 
     * @param mdModelParams 模型参数信息
     * @return 结果
     */
    @Override
    public int updateMdModelParams(MdModelParams mdModelParams)
    {
        mdModelParams.setModifyby(DateUtils.getNowDate());
        return mdModelParamsMapper.updateMdModelParams(mdModelParams);
    }

    /**
     * 批量删除模型参数信息
     * 
     * @param parIds 需要删除的模型参数信息主键
     * @return 结果
     */
    @Override
    public int deleteMdModelParamsByParIds(String[] parIds)
    {
        return mdModelParamsMapper.deleteMdModelParamsByParids(parIds);
    }

    /**
     * 删除模型参数信息信息
     * 
     * @param parId 模型参数信息主键
     * @return 结果
     */
    @Override
    public int deleteMdModelParamsByParId(String parId)
    {
        return mdModelParamsMapper.deleteMdModelParamsByParid(parId);
    }

    @Override
    public int deleteMdModelParamsByMdid(String mdid) {

        return mdModelParamsMapper.deleteMdModelParamsByMdid(mdid);
    }
}
